@@ -16,10 +16,11 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#ifndef VTE_DISABLE_DEPRECATED
+
 #ifndef vte_reaper_h_included
 #define vte_reaper_h_included
 
-
 #include <sys/wait.h>
 #include <signal.h>
 #include <glib.h>
@@ -29,8 +30,8 @@ G_BEGIN_DECLS
 
 struct _VteReaper {
 	GObject object;
-	GIOChannel *channel;
-	int iopipe[2];
+	GIOChannel *_channel; /* unused */
+	int _iopipe[2]; /* unused */
 };
 typedef struct _VteReaper VteReaper;
 
@@ -43,14 +44,14 @@ typedef struct _VteReaperClass VteReaperClass;
 GType vte_reaper_get_type(void);
 
 #define VTE_TYPE_REAPER			(vte_reaper_get_type())
-#define VTE_REAPER(obj)			(GTK_CHECK_CAST((obj), \
+#define VTE_REAPER(obj)			(G_TYPE_CHECK_INSTANCE_CAST((obj), \
 							VTE_TYPE_REAPER, \
 							VteReaper))
-#define VTE_REAPER_CLASS(klass)		GTK_CHECK_CLASS_CAST((klass), \
+#define VTE_REAPER_CLASS(klass)		G_TYPE_CHECK_CLASS_CAST((klass), \
 							     VTE_TYPE_REAPER, \
 							     VteReaperClass)
-#define VTE_IS_REAPER(obj)		GTK_CHECK_TYPE((obj), VTE_TYPE_REAPER)
-#define VTE_IS_REAPER_CLASS(klass)	GTK_CHECK_CLASS_TYPE((klass), \
+#define VTE_IS_REAPER(obj)		G_TYPE_CHECK_INSTANCE_TYPE((obj), VTE_TYPE_REAPER)
+#define VTE_IS_REAPER_CLASS(klass)	G_TYPE_CHECK_CLASS_TYPE((klass), \
 							     VTE_TYPE_REAPER)
 #define VTE_REAPER_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS((obj), \
 								   VTE_TYPE_REAPER, \
@@ -62,3 +63,5 @@ int vte_reaper_add_child(GPid pid);
 G_END_DECLS
 
 #endif
+
+#endif /* !VTE_DISABLE_DEPRECATED */
